==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Solver_interface/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"index.html#SectionSolverSVD":[0,1],
"index.html#SectionSolverSparse":[0,2],
"index.html#SolversHistory":[0,5],
"models.html":[2],
"modules.html":[1],
"namespaceCGAL.html":[4,0],
"pages.html":[],
"structCGAL_1_1Eigen__matrix.html":[1,0,1,1],
"structCGAL_1_1Eigen__matrix.html#a244e8ce36c8a5f1faa855167cde87242":[1,0,1,1,1],
"structCGAL_1_1Eigen__matrix.html#a3a230bbf53369326f2da09f442575f66":[1,0,1,1,8],
"structCGAL_1_1Eigen__matrix.html#a6783fdfa1d897687f6d2055d3866eddf":[1,0,1,1,2],
"structCGAL_1_1Eigen__matrix.html#a7d004232e5daa0463770eef913f53c04":[1,0,1,1,4],
"structCGAL_1_1Eigen__matrix.html#a806399961580d5f1960c6dff893d2350":[1,0,1,1,3],
"structCGAL_1_1Eigen__matrix.html#a8606d952c1151efec62f098787e7016b":[1,0,1,1,5],
"structCGAL_1_1Eigen__matrix.html#abc82d6cb3fd1afa7e55950c9b84aa712":[1,0,1,1,7],
"structCGAL_1_1Eigen__matrix.html#adc5ea09a9482459491933365fc7021cd":[1,0,1,1,0],
"structCGAL_1_1Eigen__matrix.html#ae30f58283cee99aa5f8991dc462e5c32":[1,0,1,1,6],
"structCGAL_1_1Eigen__sparse__matrix.html":[1,0,1,3],
"structCGAL_1_1Eigen__sparse__matrix.html#a0096cb91fa8267d24817cf4844ee68cd":[1,0,1,3,14],
"structCGAL_1_1Eigen__sparse__matrix.html#a0a3e74a4cf69af6a09f0eedfba342c8b":[1,0,1,3,16],
"structCGAL_1_1Eigen__sparse__matrix.html#a0c73de7a258776456e21e9143d9edef9":[1,0,1,3,5],
"structCGAL_1_1Eigen__sparse__matrix.html#a15b3221e84d9e274bbe35b351bef12e4":[1,0,1,3,4],
"structCGAL_1_1Eigen__sparse__matrix.html#a19535391153a349efc06a4dbd2b3b5d4":[1,0,1,3,13],
"structCGAL_1_1Eigen__sparse__matrix.html#a25c5d2bf7a141c990f28a76ef602d2cb":[1,0,1,3,3],
"structCGAL_1_1Eigen__sparse__matrix.html#a478709fe6a311a1da98a014c999ac68b":[1,0,1,3,15],
"structCGAL_1_1Eigen__sparse__matrix.html#a4b43cacc467d285c11a39f4eef7a55ae":[1,0,1,3,0],
"structCGAL_1_1Eigen__sparse__matrix.html#a6f816a2efe27466009e6c3b6c2324e13":[1,0,1,3,8],
"structCGAL_1_1Eigen__sparse__matrix.html#a8982fc4dc669b844b31caf8c730a6133":[1,0,1,3,2],
"structCGAL_1_1Eigen__sparse__matrix.html#a8aa0bc1ea9c343882d9510846441d079":[1,0,1,3,6],
"structCGAL_1_1Eigen__sparse__matrix.html#a93b103ff13bf42662b4596004f5b48d8":[1,0,1,3,7],
"structCGAL_1_1Eigen__sparse__matrix.html#aa31e888e9994bffdf1c5b02171fd348c":[1,0,1,3,10],
"structCGAL_1_1Eigen__sparse__matrix.html#aad483d93831f3264f35cbac7060f9ee1":[1,0,1,3,1],
"structCGAL_1_1Eigen__sparse__matrix.html#aba3437b5b4624ad71b7d3647af675a86":[1,0,1,3,12],
"structCGAL_1_1Eigen__sparse__matrix.html#abc014aaae0d0a76fbab94ca5bbdd5b08":[1,0,1,3,11],
"structCGAL_1_1Eigen__sparse__matrix.html#afecf3de492b7740edab0c78a62075f2f":[1,0,1,3,9],
"structCGAL_1_1Eigen__sparse__symmetric__matrix.html":[4,0,5],
"structCGAL_1_1Eigen__sparse__symmetric__matrix.html#a0aa7e541650b5178da03caf2563364bc":[4,0,5,0],
"structCGAL_1_1Eigen__sparse__symmetric__matrix.html#a315a1f43f28be232ebad3c669b956bcf":[4,0,5,1]
};

==> CGAL-6.1-doc_html.tar.xz: doc_html/Solver_interface/navtreeindex1.js <==
var NAVTREEINDEX1 =
{
"index.html#SectionSolverSparse":[0,2],
"index.html#SolversHistory":[0,5],
"modules.html":[1],
"pages.html":[],
"structCGAL_1_1Eigen__matrix.html":[1,0,1,1],
"structCGAL_1_1Eigen__matrix.html#a2300644c5d0c40890a1348dbfa8b2e3b":[1,0,1,1,4],
"structCGAL_1_1Eigen__matrix.html#a244e8ce36c8a5f1faa855167cde87242":[1,0,1,1,1],
"structCGAL_1_1Eigen__matrix.html#a3a230bbf53369326f2da09f442575f66":[1,0,1,1,8],
"structCGAL_1_1Eigen__matrix.html#a6783fdfa1d897687f6d2055d3866eddf":[1,0,1,1,2],
"structCGAL_1_1Eigen__matrix.html#a806399961580d5f1960c6dff893d2350":[1,0,1,1,3],
"structCGAL_1_1Eigen__matrix.html#a8606d952c1151efec62f098787e7016b":[1,0,1,1,5],
"structCGAL_1_1Eigen__matrix.html#abc82d6cb3fd1afa7e55950c9b84aa712":[1,0,1,1,7],
"structCGAL_1_1Eigen__matrix.html#adc5ea09a9482459491933365fc7021cd":[1,0,1,1,0],
"structCGAL_1_1Eigen__matrix.html#ae30f58283cee99aa5f8991dc462e5c32":[1,0,1,1,6],
"structCGAL_1_1Eigen__sparse__matrix.html":[1,0,1,3],
"structCGAL_1_1Eigen__sparse__matrix.html#a0096cb91fa8267d24817cf4844ee68cd":[1,0,1,3,14],
"structCGAL_1_1Eigen__sparse__matrix.html#a0a3e74a4cf69af6a09f0eedfba342c8b":[1,0,1,3,16],
"structCGAL_1_1Eigen__sparse__matrix.html#a0c73de7a258776456e21e9143d9edef9":[1,0,1,3,5],
"structCGAL_1_1Eigen__sparse__matrix.html#a15b3221e84d9e274bbe35b351bef12e4":[1,0,1,3,4],
"structCGAL_1_1Eigen__sparse__matrix.html#a19535391153a349efc06a4dbd2b3b5d4":[1,0,1,3,13],
"structCGAL_1_1Eigen__sparse__matrix.html#a25c5d2bf7a141c990f28a76ef602d2cb":[1,0,1,3,3],
"structCGAL_1_1Eigen__sparse__matrix.html#a478709fe6a311a1da98a014c999ac68b":[1,0,1,3,15],
"structCGAL_1_1Eigen__sparse__matrix.html#a4b43cacc467d285c11a39f4eef7a55ae":[1,0,1,3,0],
"structCGAL_1_1Eigen__sparse__matrix.html#a6f816a2efe27466009e6c3b6c2324e13":[1,0,1,3,8],
"structCGAL_1_1Eigen__sparse__matrix.html#a8982fc4dc669b844b31caf8c730a6133":[1,0,1,3,2],
"structCGAL_1_1Eigen__sparse__matrix.html#a8aa0bc1ea9c343882d9510846441d079":[1,0,1,3,6],
"structCGAL_1_1Eigen__sparse__matrix.html#a93b103ff13bf42662b4596004f5b48d8":[1,0,1,3,7],
"structCGAL_1_1Eigen__sparse__matrix.html#aa31e888e9994bffdf1c5b02171fd348c":[1,0,1,3,10],
"structCGAL_1_1Eigen__sparse__matrix.html#aad483d93831f3264f35cbac7060f9ee1":[1,0,1,3,1],
"structCGAL_1_1Eigen__sparse__matrix.html#ab723e53b22d2a5c075a7b71ebeb48de9":[1,0,1,3,12],
"structCGAL_1_1Eigen__sparse__matrix.html#ae4246112d6aa88e1b0e587fbf0fde7e8":[1,0,1,3,11],
"structCGAL_1_1Eigen__sparse__matrix.html#afecf3de492b7740edab0c78a62075f2f":[1,0,1,3,9],
"structCGAL_1_1Eigen__sparse__symmetric__matrix.html":[1,0,1,4],
"structCGAL_1_1Eigen__sparse__symmetric__matrix.html#a0aa7e541650b5178da03caf2563364bc":[1,0,1,4,0],
"structCGAL_1_1Eigen__sparse__symmetric__matrix.html#a315a1f43f28be232ebad3c669b956bcf":[1,0,1,4,1]
};
